@@ -7,7 +7,11 @@
 #include <QProcess>
 #include <QDebug>
 #include <QFile>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QTextCodec>
+#else
+#include <QStringConverter>
+#endif
 #include <QDir>
 #include <QElapsedTimer>
 #include <QDirIterator>
