@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="zh_CN">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
 <context>
     <name>AppSelectWidget</name>
     <message>
@@ -983,4 +981,4 @@ UOS，助您无缝更换系统</translation>
         <translation>UOS迁移工具</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
